Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
To: igt-dev@lists.freedesktop.org,
	Lucas De Marchi <lucas.demarchi@intel.com>
Subject: [PATCH i-g-t 1/8] tests/intel/xe_drm_fdinfo: Update basic test to include client utilization
Date: Sat, 22 Jun 2024 07:00:55 +0800	[thread overview]
Message-ID: <20240621230102.238397-2-umesh.nerlige.ramappa@intel.com> (raw)
In-Reply-To: <20240621230102.238397-1-umesh.nerlige.ramappa@intel.com>

Add per client utilization related checks to basic test.

Signed-off-by: Umesh Nerlige Ramappa <umesh.nerlige.ramappa@intel.com>
---
 tests/intel/xe_drm_fdinfo.c | 40 +++++++++++++++++++++++++++++++------
 1 file changed, 34 insertions(+), 6 deletions(-)

diff --git a/tests/intel/xe_drm_fdinfo.c b/tests/intel/xe_drm_fdinfo.c
index 2ceafba24..e624029b8 100644
--- a/tests/intel/xe_drm_fdinfo.c
+++ b/tests/intel/xe_drm_fdinfo.c
@@ -14,11 +14,11 @@
 #include "xe/xe_spin.h"
 /**
  * TEST: xe drm fdinfo
  * Description: Read and verify drm client memory consumption using fdinfo
  * Category: Core
  * Mega feature: General Core features
  * Sub-category: driver
  * Functionality: Per client memory statistics
  * Feature: SMI, core
  * Test category: SysMan
  *
@@ -35,10 +35,17 @@
  * Description: Create and compare active memory consumption by client
  */
 
-IGT_TEST_DESCRIPTION("Read and verify drm client memory consumption using fdinfo");
+IGT_TEST_DESCRIPTION("Read and verify drm client memory consumption and engine utilization using fdinfo");
 
 #define BO_SIZE (65536)
 
+static const char *engine_map[] = {
+	"rcs",
+	"bcs",
+	"vcs",
+	"vecs",
+	"ccs",
+};
 /* Subtests */
 static void test_active(int fd, struct drm_xe_engine *engine)
 {
@@ -259,18 +266,21 @@ static void test_total_resident(int xe)
 	xe_vm_destroy(xe, vm);
 }
 
-static void basic(int xe)
+static void basic(int xe, unsigned int num_classes)
 {
 	struct drm_xe_mem_region *memregion;
 	uint64_t memreg = all_memory_regions(xe), region;
 	struct drm_client_fdinfo info = { };
 	unsigned int ret;
 
-	ret = igt_parse_drm_fdinfo(xe, &info, NULL, 0, NULL, 0);
+	ret = igt_parse_drm_fdinfo(xe, &info, engine_map,
+				   ARRAY_SIZE(engine_map), NULL, 0);
 	igt_assert_f(ret != 0, "failed with err:%d\n", errno);
 
 	igt_assert(!strcmp(info.driver, "xe"));
 
+	igt_assert_eq(info.num_engines, num_classes);
+
 	xe_for_each_mem_region(xe, memreg, region) {
 		memregion = xe_mem_region(xe, region);
 		igt_assert(info.region_mem[memregion->instance + 1].total >=
@@ -289,19 +299,37 @@ static void basic(int xe)
 
 igt_main
 {
+	struct drm_xe_engine_class_instance *hwe;
+	unsigned int num_engines = 0, num_classes = 0;
+	unsigned int classes[16] = { };
 	int xe;
 
 	igt_fixture {
 		struct drm_client_fdinfo info = { };
+		unsigned int i;
 
 		xe = drm_open_driver(DRIVER_XE);
 		igt_require_xe(xe);
 		igt_require(igt_parse_drm_fdinfo(xe, &info, NULL, 0, NULL, 0));
+		igt_require(info.num_engines);
+
+		xe_for_each_engine(xe, hwe) {
+			num_engines++;
+			igt_assert(hwe->engine_class < ARRAY_SIZE(classes));
+			classes[hwe->engine_class]++;
+		}
+		igt_require(num_engines);
+
+		for (i = 0; i < ARRAY_SIZE(classes); i++) {
+			if (classes[i])
+				num_classes++;
+		}
+		igt_assert(num_classes);
 	}
 
 	igt_describe("Check if basic fdinfo content is present");
 	igt_subtest("basic")
-		basic(xe);
+		basic(xe, num_classes);
 
 	igt_describe("Create and compare total and resident memory consumption by client");
 	igt_subtest("drm-total-resident")
@@ -14,11 +14,11 @@
 /**
  * TEST: xe drm fdinfo
- * Description: Read and verify drm client memory consumption using fdinfo
+ * Description: Read and verify drm client memory consumption and engine utilization using fdinfo
  * Category: Core
  * Mega feature: General Core features
@@ -14,11 +14,11 @@
  * Mega feature: General Core features
  * Sub-category: driver
- * Functionality: Per client memory statistics
+ * Functionality: Per client memory and engine utilization statistics
  * Feature: SMI, core
  * Test category: SysMan
-- 
2.34.1


  reply	other threads:[~2024-06-21 23:01 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-06-21 23:00 [PATCH i-g-t 0/8] Add per-client engine utilization tests Umesh Nerlige Ramappa
2024-06-21 23:00 ` Umesh Nerlige Ramappa [this message]
2024-07-01 16:27   ` [PATCH i-g-t 1/8] tests/intel/xe_drm_fdinfo: Update basic test to include client utilization Riana Tauro
2024-07-01 18:30     ` Umesh Nerlige Ramappa
2024-07-01 16:52   ` Lucas De Marchi
2024-06-21 23:00 ` [PATCH i-g-t 2/8] tests/intel/xe_drm_fdinfo: Add helper to read utilization for all classes Umesh Nerlige Ramappa
2024-06-21 23:00 ` [PATCH i-g-t 3/8] tests/intel/xe_drm_fdinfo: Add helpers for spinning batches Umesh Nerlige Ramappa
2024-07-01 16:57   ` Lucas De Marchi
2024-07-01 17:27     ` Umesh Nerlige Ramappa
2024-07-01 18:08       ` Lucas De Marchi
2024-06-21 23:00 ` [PATCH i-g-t 4/8] tests/intel/xe_drm_fdinfo: Add single engine tests Umesh Nerlige Ramappa
2024-07-01 17:35   ` Lucas De Marchi
2024-07-01 18:26     ` Umesh Nerlige Ramappa
2024-07-02 18:18       ` Umesh Nerlige Ramappa
2024-07-02 20:57         ` Umesh Nerlige Ramappa
2024-07-02 20:57         ` Lucas De Marchi
2024-06-21 23:00 ` [PATCH i-g-t 5/8] tests/intel/xe_drm_fdinfo: Add tests to verify all class utilization Umesh Nerlige Ramappa
2024-06-21 23:01 ` [PATCH i-g-t 6/8] tests/intel/xe_drm_fdinfo: Add an iterator for virtual engines Umesh Nerlige Ramappa
2024-06-21 23:01 ` [PATCH i-g-t 7/8] tests/intel/xe_drm_fdinfo: Add tests " Umesh Nerlige Ramappa
2024-06-21 23:01 ` [PATCH i-g-t 8/8] tests/intel/xe_drm_fdinfo: Add tests for parallel engines Umesh Nerlige Ramappa
2024-06-21 23:35 ` ✓ CI.xeBAT: success for Add per-client engine utilization tests Patchwork
2024-06-21 23:44 ` ✓ Fi.CI.BAT: " Patchwork
2024-06-22  0:40 ` ✓ CI.xeFULL: " Patchwork
2024-06-22 21:32 ` ✗ Fi.CI.IGT: failure " Patchwork
2024-06-28 21:27 ` ✓ CI.xeBAT: success for Add per-client engine utilization tests (rev2) Patchwork
2024-06-28 21:37 ` ✓ Fi.CI.BAT: " Patchwork
2024-06-28 22:21 ` ✓ CI.xeFULL: " Patchwork
2024-06-29 22:53 ` ✗ Fi.CI.IGT: failure " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240621230102.238397-2-umesh.nerlige.ramappa@intel.com \
    --to=umesh.nerlige.ramappa@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    --cc=lucas.demarchi@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox